function err  = save24( x, filename, flag )
%SAVE24
%
%	Function to save data as a stream of short integers in a 
%		file.  The data is converted to type short integer.
%
%	err = save24( x, filename )
%
%	x	 - the row matrix to be saved
%	filename - a string containing the name of the output file
%
%	err	 - returns 1 if successful, 0 if unsuccessful
%
%
%OPTIONAL ARGUMENT...
%
%	err = save24( x, filename, flag)
%
%	flag = 0 the file is rewritten
%	flag = 1 the data is appended to the file
%

x = round(x);
mx = max(abs(x));

if ( mx > 32767 )
	[i,j] = find( abs(x) == mx );
	fprintf('\nsave24: x(%d,%d) = %f is too big for type SHORT INT.\n',i,j,x(i,j));
	fprintf('        DATA NOT SAVED.\n');
	err = 0;
	return;
end

permission = 'w';
if ( nargin > 2 );
	if (flag)
		permission = 'a';
		fid = fopen( filename, 'a' );
	end
end
fid = fopen( filename, permission );
if (fid==-1)
	fprintf('\nsave24: could not open file: %s\n', filename);
	fprintf('        DATA NOT SAVED.\n');
	err = 0;
	return;
end

count = fwrite(fid,x,'short');
fclose(fid);
if (count~=length(x(:)))
	fprintf('\nsave24: error in write to %s\n.', filename);
	fprintf('        Data not correctly saved.\n');
	err = 0;
	return;
end

err=1;
return;
